@@ -1,25 +1,25 @@
 from testit_python_commons.decorators import (
+    description,
+    displayName,
     externalID,
     externalId,
-    displayName,
-    workItemID,
-    workItemIds,
-    title,
-    description,
     labels,
     link,
-    links
+    links,
+    title,
+    workItemID,
+    workItemIds
 )
 from testit_python_commons.dynamic_methods import (
+    addAttachments,
     addLink,
     addLinks,
+    addMessage,
     attachments,
-    addAttachments,
-    message,
-    addMessage
+    message
 )
-from testit_python_commons.step import Step as step
 from testit_python_commons.models import LinkType
+from testit_python_commons.step import Step as step  # noqa: N813
 
 __all__ = [
     'externalID',
