@@ -1,17 +1,14 @@
-import os
 import logging
+import os
 from datetime import datetime
 
-from testit_api_client import ApiClient
-from testit_api_client import Configuration
+from testit_api_client import ApiClient, Configuration
+from testit_api_client.apis import AttachmentsApi, AutoTestsApi, TestRunsApi
 from testit_api_client.models import (
+    AttachmentPutModel,
     TestRunV2PostShortModel,
-    WorkItemIdModel,
-    AttachmentPutModel
+    WorkItemIdModel
 )
-from testit_api_client.apis import TestRunsApi
-from testit_api_client.apis import AutoTestsApi
-from testit_api_client.apis import AttachmentsApi
 
 from testit_python_commons.client.client_configuration import ClientConfiguration
 from testit_python_commons.client.converter import Converter
@@ -26,13 +23,16 @@ class ApiClientWorker:
             header_name='Authorization',
             header_value='PrivateToken ' + config.get_private_token()
         )
-
         self.__config = config
 
+        if config.get_logs() == 'true':
+            logging.basicConfig(format='\n%(levelname)s:%(message)s', level=logging.DEBUG)
+
     def create_test_run(self):
         test_run_api = TestRunsApi(api_client=self.__api_client)
 
-        test_run_name = f'TestRun_{datetime.today().strftime("%Y-%m-%dT%H:%M:%S")}' if not self.__config.get_test_run_name() else self.__config.get_test_run_name()
+        test_run_name = f'TestRun_{datetime.today().strftime("%Y-%m-%dT%H:%M:%S")}' if \
+            not self.__config.get_test_run_name() else self.__config.get_test_run_name()
         model = TestRunV2PostShortModel(
             project_id=self.__config.get_project_id(),
             name=test_run_name
@@ -40,6 +40,8 @@ class ApiClientWorker:
 
         response = test_run_api.create_empty(test_run_v2_post_short_model=model)
 
+        logging.debug(f'Test run "{response["id"]}" was created')
+
         return response['id']
 
     def set_test_run_id(self, test_run_id: str):
@@ -52,6 +54,8 @@ class ApiClientWorker:
 
         test_results = response['_data_store']['test_results']
 
+        logging.debug(f'{len(test_results)} autotests were taken from the test run "{self.__config.get_test_run_id()}"')
+
         return Utils.autotests_parser(
             test_results,
             self.__config.get_configuration_id())
@@ -62,8 +66,10 @@ class ApiClientWorker:
 
         autotest = autotest_api.get_all_auto_tests(project_id=self.__config.get_project_id(),
                                                    external_id=test_result['externalID'])
-        autotest_global_id = None
+
         if autotest:
+            logging.debug(f'Autotest "{test_result["autoTestName"]}" was found')
+
             model = Converter.test_result_to_autotest_put_model(
                 test_result,
                 self.__config.get_project_id())
@@ -71,7 +77,10 @@ class ApiClientWorker:
             autotest_api.update_auto_test(auto_test_put_model=model)
             autotest_global_id = autotest[0]['id']
 
+            logging.debug(f'Autotest "{test_result["autoTestName"]}" was updated')
         else:
+            logging.debug(f'Autotest "{test_result["autoTestName"]}" was not found')
+
             model = Converter.test_result_to_autotest_post_model(
                 test_result,
                 self.__config.get_project_id())
@@ -79,14 +88,18 @@ class ApiClientWorker:
             autotest_response = autotest_api.create_auto_test(auto_test_post_model=model)
             autotest_global_id = autotest_response['id']
 
+            logging.debug(f'Autotest "{test_result["autoTestName"]}" was created')
+
         if autotest_global_id:
             for work_item_id in test_result['workItemsID']:
                 try:
                     autotest_api.link_auto_test_to_work_item(
                         autotest_global_id,
                         work_item_id_model=WorkItemIdModel(id=work_item_id))
+
+                    logging.debug(f'Autotest "{test_result["autoTestName"]}" was linked with workItem "{work_item_id}"')
                 except Exception as exc:
-                    logging.error(f"Link with workItem {work_item_id} status: {exc.status}\n{exc.body}")
+                    logging.error(f'Link with workItem "{work_item_id}" status: {exc.status}\n{exc.body}')
 
         model = Converter.test_result_to_testrun_result_post_model(
             test_result,
@@ -96,6 +109,9 @@ class ApiClientWorker:
             id=self.__config.get_test_run_id(),
             auto_test_results_for_test_run_model=[model])
 
+        logging.debug(f'Result of the autotest "{test_result["autoTestName"]}" was set '
+                      f'in the test run "{self.__config.get_test_run_id()}"')
+
     def load_attachments(self, attach_paths: list or tuple):
         attachments_api = AttachmentsApi(api_client=self.__api_client)
 
@@ -106,8 +122,10 @@ class ApiClientWorker:
                     attachment_response = attachments_api.api_v2_attachments_post(file=open(path, "rb"))
 
                     attachments.append(AttachmentPutModel(attachment_response['id']))
+
+                    logging.debug(f'Attachment "{path}" was uploaded')
                 except Exception as exc:
-                    logging.error(f'Load {path} status: {exc.status}\n{exc.body}')
+                    logging.error(f'Upload attachment "{path}" status: {exc.status}\n{exc.body}')
             else:
-                logging.error(f'File ({path}) not found!')
+                logging.error(f'File "{path}" was not found!')
         return attachments
